@@ -134,7 +134,7 @@ class OMS:
 		for order in executed_orders:
 			if order['status'] not in ['COMPLETED', 'CANCELLED']:
 				continue
-				
+			
 			if order['status'] == 'CANCELLED' and order['filled_qty'] == 0:
 				continue
 			
@@ -150,7 +150,7 @@ class OMS:
 			elif exchange == 'NSE' and trade_type == 'INTRADAY':
 				brokerage = min(0.03 / 100 * order_value, 20)
 				stt = 0.025 / 100 * order_value if order['action'] == 'Sell' else 0
-				transaction_charges = 0.00322 / 100 * order_value if exchange == 'NSE' else 0.00375 / 100 * order_value
+				transaction_charges = 0.00297 / 100 * order_value if exchange == 'NSE' else 0.00375 / 100 * order_value
 				stamp_charges = 0.003 / 100 * order_value if order['action'] == 'Buy' else 0
 			
 			elif exchange in ['NFO', 'BFO'] and order['ticker'].split()[-1] == 'FUT':
@@ -358,7 +358,7 @@ class OMS:
 		else:
 			return all_orders
 	
-	def place_gtt_order(self, buy_price, trade_type, qty, thresh=1.0, slippage=0.98, ticker=None, prefix=None,
+	def place_gtt_order(self, action, buy_price, trade_type, qty, thresh=1.0, slippage=0.98, ticker=None, prefix=None,
 	                    strike=None, exchange='NFO'):
 		base_price, ticker = base(buy_price * thresh), ticker or f'{prefix}{strike}'
 		
@@ -370,7 +370,7 @@ class OMS:
 		
 		condition = {'exchange': exchange, 'tradingsymbol': ticker, 'trigger_values': [base_price],
 		             'last_price': ltp[ticker]}
-		orders = [{'exchange': exchange, 'tradingsymbol': ticker, 'transaction_type': 'SELL', 'quantity': qty,
+		orders = [{'exchange': exchange, 'tradingsymbol': ticker, 'transaction_type': action, 'quantity': qty,
 		           'order_type': 'LIMIT', 'product': trade_type, 'price': base(base_price * slippage)}]
 		data = {'condition': json.dumps(condition), 'orders': json.dumps(orders), 'type': 'single'}
 		
@@ -382,7 +382,7 @@ class OMS:
 		
 		return res
 	
-	def modify_gtt_order(self, order_id, trigger_price, execution_price, trade_type, qty, ticker, exchange):
+	def modify_gtt_order(self, action, order_id, trigger_price, execution_price, trade_type, qty, ticker, exchange):
 		ltp = self.ltp(f'{exchange}:{ticker}')
 		if ltp is None:
 			return 'invalid ticker'
@@ -391,7 +391,7 @@ class OMS:
 		
 		condition = {'exchange': exchange, 'tradingsymbol': ticker, 'trigger_values': [base(trigger_price)],
 		             'last_price': ltp[ticker]}
-		orders = [{'exchange': exchange, 'tradingsymbol': ticker, 'transaction_type': 'SELL', 'quantity': qty,
+		orders = [{'exchange': exchange, 'tradingsymbol': ticker, 'transaction_type': action, 'quantity': qty,
 		           'order_type': 'LIMIT', 'product': trade_type, 'price': base(execution_price)}]
 		data = {'condition': json.dumps(condition), 'orders': json.dumps(orders), 'type': 'single'}
 		
@@ -435,7 +435,8 @@ if __name__ == '__main__':
 		print(obj.ltp(['NSE:RELIANCE']))
 		print(obj.quote(['NSE:RELIANCE']))
 		print(obj.get_user())
-		print(obj.get_cash_needed(exchange='NSE', ticker='RELIANCE', action='BUY', price=2000, qty=1, price_type='LIMIT'))
+		print(
+			obj.get_cash_needed(exchange='NSE', ticker='RELIANCE', action='BUY', price=2000, qty=1, price_type='LIMIT'))
 		print(obj.get_cash_details())
 		obj.get_instruments()
 		print(obj.get_tax_details())
@@ -447,9 +448,10 @@ if __name__ == '__main__':
 		print(obj.get_gtt_orders())
 		print(obj.place_gtt_order(buy_price=20, trade_type='MIS', qty=50, thresh=0.9, slippage=0.98,
 		                          ticker='MIDCPNIFTY2490913050PE'))
-
+		
 		print(obj.modify_gtt_order(
-			**{"order_id": 237156502, "exchange": "BFO", "ticker": "SENSEX2491381200PE", "qty": 500, "trigger_price": 575,
+			**{"order_id": 237156502, "exchange": "BFO", "ticker": "SENSEX2491381200PE", "qty": 500,
+			   "trigger_price": 575,
 			   "execution_price": 450, "trade_type": "NRML"}))
 		print(obj.cancel_gtt_order(order_ids=['237156502']))
 		
